| coordinates | R Documentation |
Generates coordinates along a circular path.
coordinates(a, r)
a |
Numeric vector of angles (degrees). |
r |
Numeric scalar of the circle radius. |
Calculates xy coordinates along a circular path given a vector of angles and a specified radius. The center of the circle is at the origin (i.e., x = 0, y = 0). This function is helpful for calculating the vertices of circle and sector polygons.
A numeric matrix of xy coordinates.
circle for plotting circle polygons.
sector for plotting sector polygons.
coordinates(a=c(90,180,270,360),r=1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.