detection: Grouped Detection Plot

View source: R/detection.R

detectionR Documentation

Grouped Detection Plot

Description

Generates detection plots for multiple groups.

Usage

detection(
  x,
  r = 1,
  b = 0.025,
  v = 1000,
  w = 1,
  f = 0.5,
  c = "lightskyblue",
  m = 3,
  ...
)

Arguments

x

A list of vectors named "g", "s", "r", and "d". The elements of vector "g" (character, numeric, or factor) specify the group. The elements of vector "s" (character or numeric) specify the sample. The elements of vector "r" (numeric) specify the number of replicates within sample "s". The elements of vector "d" (numeric) specify the number of replicates within sample "s" with detections.

r

Numeric scalar. Radius of plot circle (default = 1).

b

Numeric scalar. Plot radius buffer (proportion; default = 0.025).

v

Numeric scalar. Vertex count of plot circle (default = 1000).

w

Numeric scalar. Line width of outer circle (default = 1).

f

Numeric scalar. Line width of sectors as a proportion of w (default = 0.5).

c

Character string. Fill color of sub-sector detections (default = "lightskyblue").

m

Numeric scalar. Maximum number of plot columns (default = 3).

...

Additional arguments passed to title.

Details

Produces a pie-chart-like detection plot with grouping structure. Each circle represents a group. Each sector represents a sample, and each sub-sector represents a replicate. Filled replicates represent detections. Groups are sorted alphabetically (or inherit factor level ordering) and arranged from left to right and top to bottom. Samples are sorted alphabetically and arranged in a clockwise orientation (from angle zero). Samples are sorted independently for each group. This plot design is specialized for visualizing binary detection data.

Value

No return value.

References

A manuscript describing this plot design is in preparation.

See Also

singular.detection for singular detection plots.

proportion for grouped proportion plots.

Examples


set.seed(1234)
n.groups<-6
n.samples<-6
n.replicates<-3
data<-list(g=rep(x=LETTERS[1:n.groups],each=n.samples),
           s=rep(x=letters[1:n.samples],times=n.groups),
           r=rep(x=n.replicates,times=n.groups*n.samples),
           d=sample(x=0:n.replicates,size=n.groups*n.samples,
                    replace=TRUE))
detection(x=data)


LocaTT documentation built on June 14, 2026, 1:06 a.m.