dmvlogis: Density of the Multivariate Logistic Distribution

View source: R/dmvlogis.R

dmvlogisR Documentation

Density of the Multivariate Logistic Distribution

Description

Density function for the multivariate logistic distribution.

Usage

dmvlogis(x, location, scale, R, log = FALSE)

Arguments

x

Numeric vector or matrix. Values of logistically-distributed marginals. If matrix, then a vector of probability densities is returned with an element for each record of the matrix. Matrix records represent observations, and matrix fields represent dimensions.

location

Numeric vector. Location parameters of the logistic distribution. If x is a matrix, then location is recycled for each record of matrix x.

scale

Numeric vector. Scale parameters of the logistic distribution. If x is a matrix, then scale is recycled for each record of matrix x.

R

Numeric correlation matrix. If x is a matrix, then R is recycled for each record of matrix x.

log

Logical scalar. If TRUE, then probabilities are given as log(density).

Details

Computes the probability density of the multivariate logistic distribution. The multivariate logistic distribution is constructed using a Gaussian copula with logistic marginals. The probability density is the product of the densities of the logistic marginals, which is further multiplied by the density of a Gaussian copula of the transformed standard uniform margins (i.e., probability integral transformation of the logistic marginals with stats::plogis).

Value

Numeric vector of probability densities.

References

Decani JS, and Stine RA. 1986. A note on deriving the information matrix for a logistic distribution. The American Statistician, 40(3): 220-222. DOI: 10.2307/2684541

Song P. 2000. Multivariate dispersion models generated from Gaussian copula. Scandinavian Journal of Statistics, 27(2): 305-320. DOI: 10.1111/1467-9469.00191

See Also

stats::dlogis for density of the logistic distribution.

dcopula for density of the Gaussian copula.

Examples

# Define logistic margins.
x<-c(0.055,-1.625,0.329,-5.765)

# Define location parameters.
location<-c(0.477,-0.998,-0.776,0.064)

# Define scale parameters.
scale<-c(0.574,1.314,0.460,1.393)

# Define correlation matrix.
R<-matrix(data=c(1.000,-0.80,0.64,-0.512,
                 -0.800,1.00,-0.80,0.640,
                 0.640,-0.80,1.00,-0.800,
                 -0.512,0.64,-0.80,1.000),
           ncol=4,byrow=TRUE)

# Compute log probability density.
dmvlogis(x=x,location=location,
         scale=scale,R=R,
         log=TRUE)

LocaTT documentation built on June 14, 2026, 1:06 a.m.