| mlcor | R Documentation |
Extract residual correlations from multivariate logistic regression models.
mlcor(fit, probs = c(0.025, 0.25, 0.5, 0.75, 0.975), dimnames)
fit |
A |
probs |
Numeric vector of probabilities. Passed to the |
dimnames |
List (optional). If provided, then names within the returned 3-dimensional array will receive these values. Passed to the |
Extracts residual correlation estimates from a multivariate logistic regression model fit using the mlreg function. Summarizes estimates by the quantiles of their posterior distributions, and returns summaries in a 3-dimensional array. The dimensions of the 3D array represent the posterior quantiles (dimension 1) and the response variables (both dimensions 2 and 3). Values at probs = 0.025 and 0.975 comprise 95% credible intervals. Values at probs = 0.25 and 0.75 comprise 50% credible intervals, and values at probs = 0.5 represent point estimates.
Numeric 3-dimensional array of residual correlation posterior quantiles.
mlreg for fitting multivariate logistic regression models.
mlcoef for extracting regression coefficients from multivariate logistic regression models.
mlformat for formatting output of multivariate logistic regression models.
# Define example data file path.
path<-system.file("extdata",
"example_mvlogistic_data.rds",
package="LocaTT",
mustWork=TRUE)
# Read in example regression data.
data<-readRDS(file=path)
# Extract residual correlations.
out<-mlcor(fit=data$fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.