proportion: Grouped Proportion Plot

View source: R/proportion.R

proportionR Documentation

Grouped Proportion Plot

Description

Generates proportion plots for multiple groups.

Usage

proportion(
  x,
  r = 1,
  b = 0.025,
  v = 1000,
  w = 1,
  f = 0.5,
  c = "lightskyblue",
  s = FALSE,
  a = TRUE,
  m = 3,
  ...
)

Arguments

x

A list of vectors named "g", "s", and "p". The elements of vector "g" (character, numeric, or factor) specify the group. The elements of vector "s" (character or numeric) specify the sample. The elements of vector "p" (numeric) specify the proportional abundance within sample "s".

r

Numeric scalar. Radius of plot circle (default = 1).

b

Numeric scalar. Plot radius buffer (proportion; default = 0.025).

v

Numeric scalar. Vertex count of plot circle (default = 1000).

w

Numeric scalar. Line width of outer circle (default = 1).

f

Numeric scalar. Line width of sectors as a proportion of w (default = 0.5).

c

Character string. Fill color of sector proportions (default = "lightskyblue").

s

Logical value. If FALSE (the default), sort samples alphabetically. If TRUE, sort samples by decreasing proportional abundance. Samples are sorted independently for each group.

a

Logical value. If FALSE, proportional abundance is represented by the fraction of filled sector radius to outer sector radius. If TRUE (the default), proportional abundance is represented by the fraction of filled sector area to outer sector area.

m

Numeric scalar. Maximum number of plot columns (default = 3).

...

Additional arguments passed to title.

Details

Produces a pie-chart-like proportion plot with grouping structure. Each circle represents a group, and each sector represents a sample. When a = TRUE (the default), then the proportion of each sector filled with color represents the within-sample proportional abundance. Groups are sorted alphabetically (or inherit factor level ordering) and arranged from left to right and top to bottom. When s = FALSE (the default), then samples are sorted alphabetically and arranged in a clockwise orientation (from angle zero). When s = TRUE, then samples are sorted by decreasing proportional abundance. Samples are sorted independently for each group. This plot design is specialized for visualizing proportional abundance data.

Value

No return value.

References

A manuscript describing this plot design is in preparation.

See Also

singular.proportion for singular proportion plots.

detection for grouped detection plots.

Examples


set.seed(1234)
n.groups<-6
n.samples<-6
data<-list(g=rep(x=LETTERS[1:n.groups],each=n.samples),
           s=rep(x=letters[1:n.samples],times=n.groups),
           p=stats::rbeta(n=n.groups*n.samples,
                          shape1=1,shape2=1))
proportion(x=data)


LocaTT documentation built on June 14, 2026, 1:06 a.m.