| sector | R Documentation |
Draws sector polygon.
sector(s, e, r, v = 1000, ...)
s |
Numeric scalar of start angle (degrees). |
e |
Numeric scalar of end angle (degrees). |
r |
Numeric scalar of circle radius. |
v |
Numeric scalar of full-circle vertex count (default = |
... |
Additional arguments passed to |
Draws a sector polygon given a start angle, end angle, and circle radius. The sector is drawn about the origin (i.e., x = 0, y = 0). Intended for use with template to generate detection and proportion plots.
No return value.
circle for plotting circle polygons.
template(l=1)
sector(s=0,e=45,r=1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.