singular.detection: Singular Detection Plot

View source: R/singular.detection.R

singular.detectionR Documentation

Singular Detection Plot

Description

Generates a detection plot for a singular group.

Usage

singular.detection(
  x,
  r = 1,
  b = 0.025,
  v = 1000,
  w = 1,
  f = 0.5,
  c = "lightskyblue",
  t = "",
  ...
)

Arguments

x

A list of vectors named "s", "r", and "d". The elements of vector "s" (character or numeric) specify the sample. The elements of vector "r" (numeric) specify the number of replicates within sample "s". The elements of vector "d" (numeric) specify the number of replicates within sample "s" with detections.

r

Numeric scalar. Radius of plot circle (default = 1).

b

Numeric scalar. Plot radius buffer (proportion; default = 0.025).

v

Numeric scalar. Vertex count of plot circle (default = 1000).

w

Numeric scalar. Line width of outer circle (default = 1).

f

Numeric scalar. Line width of sectors as a proportion of w (default = 0.5).

c

Character string. Fill color of sub-sector detections (default = "lightskyblue").

t

Character string. Plot title (default = "").

...

Additional arguments passed to title.

Details

Produces a pie-chart-like detection plot without grouping structure. Each sector represents a sample, and each sub-sector represents a replicate. Filled replicates represent detections. Samples are sorted alphabetically and arranged in a clockwise orientation (from angle zero). This plot design is specialized for visualizing binary detection data.

Value

No return value.

References

A manuscript describing this plot design is in preparation.

See Also

detection for grouped detection plots.

proportion for grouped proportion plots.

Examples


set.seed(1234)
n.samples<-6
n.replicates<-3
data<-list(s=letters[1:n.samples],
           r=rep(x=n.replicates,times=n.samples),
           d=sample(x=0:n.replicates,size=n.samples,
                    replace=TRUE))
singular.detection(x=data)


LocaTT documentation built on June 14, 2026, 1:06 a.m.