template: Initiate Template Plot

View source: R/template.R

templateR Documentation

Initiate Template Plot

Description

Initiates a blank template plot.

Usage

template(l, b = 0.025)

Arguments

l

Numeric scalar of axis limits (applies to both axes).

b

Numeric scalar to extend axis limits (see Details; default = 0.025).

Details

Initiates a blank template plot with limits l and buffer b about the origin (i.e., x = 0, y = 0). l is used for axis limits in both the negative and positive directions. b extends the limits beyond l by a fixed proportion (i.e., l * (1 + b)). Intended for use with circle and sector.

Value

No return value.

See Also

circle for plotting circle polygons.

sector for plotting sector polygons.

Examples


template(l=1)
circle(r=1)


LocaTT documentation built on June 14, 2026, 1:06 a.m.