View source: R/adjust_taxonomies.R
| adjust_taxonomies | R Documentation |
Performs adjustments to a taxonomy system according to a taxonomy edits file.
adjust_taxonomies(
path_to_input_file,
path_to_output_file,
path_to_taxonomy_edits
)
path_to_input_file |
String specifying path to list of species (in CSV format) whose taxonomies are to be adjusted. The file should contain the following fields: 'Common_Name', 'Domain', 'Phylum', 'Class', 'Order', 'Family', 'Genus', 'Species'. There should be no |
path_to_output_file |
String specifying path to output species list with adjusted taxonomies. The output file will be in CSV format. |
path_to_taxonomy_edits |
String specifying path to taxonomy edits file in CSV format. The file must contain the following fields: 'Old_Taxonomy', 'New_Taxonomy', 'Notes'. Old taxonomies are replaced with new taxonomies in the order the records appear in the file. The taxonomic levels in the 'Old_Taxonomy' and 'New_Taxonomy' fields should be delimited by a semi-colon. |
No return value. Writes an output CSV file with adjusted taxonomies.
get_taxonomies.species_binomials for remotely fetching NCBI taxonomies from species binomials.
get_taxonomies.IUCN for formatting taxonomies from the IUCN Red List.
# Get path to input file.
path_to_input_file<-system.file("extdata",
"example_local_taxa_list.csv",
package="LocaTT",
mustWork=TRUE)
# Get path to taxonomy edits.
path_to_taxonomy_edits<-system.file("extdata",
"example_taxonomy_edits.csv",
package="LocaTT",
mustWork=TRUE)
# Create temporary output file path.
path_to_output_file<-tempfile(fileext=".csv")
# Adjust taxonomies.
adjust_taxonomies(path_to_input_file=path_to_input_file,
path_to_output_file=path_to_output_file,
path_to_taxonomy_edits=path_to_taxonomy_edits)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.