| detection | R Documentation |
Generates detection plots for multiple groups.
detection(
x,
r = 1,
b = 0.025,
v = 1000,
w = 1,
f = 0.5,
c = "lightskyblue",
m = 3,
...
)
x |
A list of vectors named |
r |
Numeric scalar. Radius of plot circle (default = |
b |
Numeric scalar. Plot radius buffer (proportion; default = |
v |
Numeric scalar. Vertex count of plot circle (default = |
w |
Numeric scalar. Line width of outer circle (default = |
f |
Numeric scalar. Line width of sectors as a proportion of |
c |
Character string. Fill color of sub-sector detections (default = |
m |
Numeric scalar. Maximum number of plot columns (default = |
... |
Additional arguments passed to |
Produces a pie-chart-like detection plot with grouping structure. Each circle represents a group. Each sector represents a sample, and each sub-sector represents a replicate. Filled replicates represent detections. Groups are sorted alphabetically (or inherit factor level ordering) and arranged from left to right and top to bottom. Samples are sorted alphabetically and arranged in a clockwise orientation (from angle zero). Samples are sorted independently for each group. This plot design is specialized for visualizing binary detection data.
No return value.
A manuscript describing this plot design is in preparation.
singular.detection for singular detection plots.
proportion for grouped proportion plots.
set.seed(1234)
n.groups<-6
n.samples<-6
n.replicates<-3
data<-list(g=rep(x=LETTERS[1:n.groups],each=n.samples),
s=rep(x=letters[1:n.samples],times=n.groups),
r=rep(x=n.replicates,times=n.groups*n.samples),
d=sample(x=0:n.replicates,size=n.groups*n.samples,
replace=TRUE))
detection(x=data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.