| dmvlogis | R Documentation |
Density function for the multivariate logistic distribution.
dmvlogis(x, location, scale, R, log = FALSE)
x |
Numeric vector or matrix. Values of logistically-distributed marginals. If matrix, then a vector of probability densities is returned with an element for each record of the matrix. Matrix records represent observations, and matrix fields represent dimensions. |
location |
Numeric vector. Location parameters of the logistic distribution. If |
scale |
Numeric vector. Scale parameters of the logistic distribution. If |
R |
Numeric correlation matrix. If |
log |
Logical scalar. If |
Computes the probability density of the multivariate logistic distribution. The multivariate logistic distribution is constructed using a Gaussian copula with logistic marginals. The probability density is the product of the densities of the logistic marginals, which is further multiplied by the density of a Gaussian copula of the transformed standard uniform margins (i.e., probability integral transformation of the logistic marginals with stats::plogis).
Numeric vector of probability densities.
Decani JS, and Stine RA. 1986. A note on deriving the information matrix for a logistic distribution. The American Statistician, 40(3): 220-222. DOI: 10.2307/2684541
Song P. 2000. Multivariate dispersion models generated from Gaussian copula. Scandinavian Journal of Statistics, 27(2): 305-320. DOI: 10.1111/1467-9469.00191
stats::dlogis for density of the logistic distribution.
dcopula for density of the Gaussian copula.
# Define logistic margins.
x<-c(0.055,-1.625,0.329,-5.765)
# Define location parameters.
location<-c(0.477,-0.998,-0.776,0.064)
# Define scale parameters.
scale<-c(0.574,1.314,0.460,1.393)
# Define correlation matrix.
R<-matrix(data=c(1.000,-0.80,0.64,-0.512,
-0.800,1.00,-0.80,0.640,
0.640,-0.80,1.00,-0.800,
-0.512,0.64,-0.80,1.000),
ncol=4,byrow=TRUE)
# Compute log probability density.
dmvlogis(x=x,location=location,
scale=scale,R=R,
log=TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.