View source: R/get_taxonomies.IUCN.R
| get_taxonomies.IUCN | R Documentation |
Formats taxonomies from IUCN Red List taxonomy.csv and common_names.csv files for use with the local_taxa_tool function.
get_taxonomies.IUCN(
path_to_taxonomies,
path_to_common_names,
path_to_output_file,
domain = "Eukaryota",
path_to_taxonomy_edits = NA,
...
)
path_to_taxonomies |
String specifying path to input IUCN Red List taxonomy.csv file. |
path_to_common_names |
String specifying path to input IUCN Red List common_names.csv file. |
path_to_output_file |
String specifying path to output species list (in CSV format) with formatted taxonomies. |
domain |
String specifying the domain name to use for all species. The IUCN Red List files do not include domain information, so a domain name must be provided. If using a reference database from UNITE, provide a kingdom name here (e.g., |
path_to_taxonomy_edits |
String specifying path to taxonomy edits file in CSV format. The file must contain the following fields: 'Old_Taxonomy', 'New_Taxonomy', 'Notes'. Old taxonomies are replaced with new taxonomies in the order the records appear in the file. The taxonomic levels in the 'Old_Taxonomy' and 'New_Taxonomy' fields should be delimited by a semi-colon. If no taxonomy edits are desired, then set this variable to |
... |
Accepts former argument names for backwards compatibility. |
No return value. Writes an output CSV file with formatted taxonomies.
get_taxonomies.species_binomials for remotely fetching NCBI taxonomies from species binomials.
adjust_taxonomies for adjusting a taxonomy system.
# Get path to example taxonomy CSV file.
path_to_taxonomies<-system.file("extdata",
"example_taxonomy.csv",
package="LocaTT",
mustWork=TRUE)
# Get path to example common names CSV file.
path_to_common_names<-system.file("extdata",
"example_common_names.csv",
package="LocaTT",
mustWork=TRUE)
# Create a temporary file path for the output CSV file.
path_to_output_file<-tempfile(fileext=".csv")
# Format common names and taxonomies.
get_taxonomies.IUCN(path_to_taxonomies=path_to_taxonomies,
path_to_common_names=path_to_common_names,
path_to_output_file=path_to_output_file)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.