View source: R/get_taxonomies.species_binomials.R
| get_taxonomies.species_binomials | R Documentation |
Remotely fetches taxonomies from the NCBI taxonomy database for a list of species binomials. Installation of the taxize package is required to use this function.
get_taxonomies.species_binomials(
path_to_species_binomials,
path_to_output_file,
path_to_taxonomy_edits = NA,
print_queries = TRUE,
...
)
path_to_species_binomials |
String specifying path to input species list with common and scientific names. The file should be in CSV format and contain the following fields: 'Common_Name', 'Scientific_Name'. Values in the 'Common_Name' field are optional. Values in the 'Scientific_Name' field are required. |
path_to_output_file |
String specifying path to output species list with added NCBI taxonomies. The output file will be in CSV format. |
path_to_taxonomy_edits |
String specifying path to taxonomy edits file in CSV format. The file must contain the following fields: 'Old_Taxonomy', 'New_Taxonomy', 'Notes'. Old taxonomies are replaced with new taxonomies in the order the records appear in the file. The taxonomic levels in the 'Old_Taxonomy' and 'New_Taxonomy' fields should be delimited by a semi-colon. If no taxonomy edits are desired, then set this variable to |
print_queries |
Logical. Whether taxa queries should be printed. The default is |
... |
Accepts former argument names for backwards compatibility. |
No return value. Writes an output CSV file with added taxonomies. Species which could not be found in the NCBI taxonomy database appear in the top records of the output file.
get_taxonomies.IUCN for formatting taxonomies from the IUCN Red List.
adjust_taxonomies for adjusting a taxonomy system.
# Get path to example input species binomials CSV file.
path_to_species_binomials<-system.file("extdata",
"example_species_binomials.csv",
package="LocaTT",
mustWork=TRUE)
# Create a temporary file path for the output CSV file.
path_to_output_file<-tempfile(fileext=".csv")
# Fetch taxonomies from species binomials.
get_taxonomies.species_binomials(path_to_species_binomials=path_to_species_binomials,
path_to_output_file=path_to_output_file,
print_queries=FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.