View source: R/singular.detection.R
| singular.detection | R Documentation |
Generates a detection plot for a singular group.
singular.detection(
x,
r = 1,
b = 0.025,
v = 1000,
w = 1,
f = 0.5,
c = "lightskyblue",
t = "",
...
)
x |
A list of vectors named |
r |
Numeric scalar. Radius of plot circle (default = |
b |
Numeric scalar. Plot radius buffer (proportion; default = |
v |
Numeric scalar. Vertex count of plot circle (default = |
w |
Numeric scalar. Line width of outer circle (default = |
f |
Numeric scalar. Line width of sectors as a proportion of |
c |
Character string. Fill color of sub-sector detections (default = |
t |
Character string. Plot title (default = |
... |
Additional arguments passed to |
Produces a pie-chart-like detection plot without grouping structure. Each sector represents a sample, and each sub-sector represents a replicate. Filled replicates represent detections. Samples are sorted alphabetically and arranged in a clockwise orientation (from angle zero). This plot design is specialized for visualizing binary detection data.
No return value.
A manuscript describing this plot design is in preparation.
detection for grouped detection plots.
proportion for grouped proportion plots.
set.seed(1234)
n.samples<-6
n.replicates<-3
data<-list(s=letters[1:n.samples],
r=rep(x=n.replicates,times=n.samples),
d=sample(x=0:n.replicates,size=n.samples,
replace=TRUE))
singular.detection(x=data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.