View source: R/singular.proportion.R
| singular.proportion | R Documentation |
Generates a proportion plot for a singular group.
singular.proportion(
x,
r = 1,
b = 0.025,
v = 1000,
w = 1,
f = 0.5,
c = "lightskyblue",
t = "",
s = FALSE,
a = TRUE,
...
)
x |
A list of vectors named |
r |
Numeric scalar. Radius of plot circle (default = |
b |
Numeric scalar. Plot radius buffer (proportion; default = |
v |
Numeric scalar. Vertex count of plot circle (default = |
w |
Numeric scalar. Line width of outer circle (default = |
f |
Numeric scalar. Line width of sectors as a proportion of |
c |
Character string. Fill color of sector proportions (default = |
t |
Character string. Plot title (default = |
s |
Logical value. If |
a |
Logical value. If |
... |
Additional arguments passed to |
Produces a pie-chart-like proportion plot without grouping structure. Each sector represents a sample. When a = TRUE (the default), then the proportion of each sector filled with color represents the within-sample proportional abundance. When s = FALSE (the default), then samples are sorted alphabetically and arranged in a clockwise orientation (from angle zero). When s = TRUE, then samples are sorted by decreasing proportional abundance. This plot design is specialized for visualizing proportional abundance data.
No return value.
A manuscript describing this plot design is in preparation.
proportion for grouped proportion plots.
singular.detection for singular detection plots.
set.seed(1234)
n.samples<-6
data<-list(s=letters[1:n.samples],
p=stats::rbeta(n=n.samples,
shape1=1,shape2=1))
singular.proportion(x=data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.