| template | R Documentation |
Initiates a blank template plot.
template(l, b = 0.025)
l |
Numeric scalar of axis limits (applies to both axes). |
b |
Numeric scalar to extend axis limits (see Details; default = |
Initiates a blank template plot with limits l and buffer b about the origin (i.e., x = 0, y = 0). l is used for axis limits in both the negative and positive directions. b extends the limits beyond l by a fixed proportion (i.e., l * (1 + b)). Intended for use with circle and sector.
No return value.
circle for plotting circle polygons.
sector for plotting sector polygons.
template(l=1)
circle(r=1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.